@@ -1,5 +1,10 @@
-get_modeldata <- function(model, additional_variables = FALSE, modeldata = NULL, wts = FALSE, ...) {
-
+get_modeldata <- function(
+    model,
+    additional_variables = FALSE,
+    modeldata = NULL,
+    wts = FALSE,
+    ...
+) {
     # mice
     if (inherits(model, c("mira", "amest"))) {
         return(modeldata)
@@ -12,7 +17,9 @@ get_modeldata <- function(model, additional_variables = FALSE, modeldata = NULL,
         if ("fit" %in% names(model)) {
             tmp <- try(get_modeldata(model$fit), silent = TRUE)
             if (inherits(tmp, "data.frame")) {
-                return(tmp)
+                out <- unpack_matrix_1col(tmp)
+                data.table::setDT(out)
+                return(out)
             }
         }
         return(NULL)
@@ -21,6 +28,8 @@ get_modeldata <- function(model, additional_variables = FALSE, modeldata = NULL,
     # otherwise, insight::get_data can sometimes return only the the outcome variable
     if (inherits(model, "bart")) {
         modeldata <- insight::get_data(model, additional_variables = TRUE)
+        modeldata <- unpack_matrix_1col(modeldata)
+        data.table::setDT(modeldata)
         return(modeldata)
     }
 
@@ -45,11 +54,18 @@ get_modeldata <- function(model, additional_variables = FALSE, modeldata = NULL,
         additional_variables <- c(additional_variables, fwts)
     }
 
+    # always need weights in this model class
+    if (any(c("svylm", "svyglm") %in% class(model))) {
+        wts <- TRUE
+    }
+
     # after by
     if (isTRUE(checkmate::check_flag(additional_variables))) {
         out <- hush(insight::get_data(
-            model, additional_variables = additional_variables, verbose = FALSE)
-        )
+            model,
+            additional_variables = additional_variables,
+            verbose = FALSE
+        ))
         out <- set_variable_class(out, model = model)
         return(out)
     }
@@ -60,7 +76,10 @@ get_modeldata <- function(model, additional_variables = FALSE, modeldata = NULL,
         additional_variables <- c(additional_variables, hush(all.vars(off)))
     } else if (isTRUE(checkmate::check_character(off, max.len = 4))) {
         if (isTRUE(grepl("~", off))) {
-            additional_variables <- c(additional_variables, hush(all.vars(stats::as.formula(off))))
+            additional_variables <- c(
+                additional_variables,
+                hush(all.vars(stats::as.formula(off)))
+            )
         } else {
             additional_variables <- c(additional_variables, off)
         }
@@ -72,38 +91,45 @@ get_modeldata <- function(model, additional_variables = FALSE, modeldata = NULL,
         additional_variables <- c(additional_variables, hush(all.vars(wtsvname)))
     } else if (isTRUE(checkmate::check_character(wtsvname, max.len = 4))) {
         if (isTRUE(grepl("~", wtsvname))) {
-            additional_variables <- c(additional_variables, hush(all.vars(stats::as.formula(wtsvname))))
+            additional_variables <- c(
+                additional_variables,
+                hush(all.vars(stats::as.formula(wtsvname)))
+            )
         } else {
             additional_variables <- c(additional_variables, wtsvname)
         }
     }
 
-    out <- hush(insight::get_data(model, verbose = FALSE, additional_variables = additional_variables))
+    out <- hush(insight::get_data(
+        model,
+        verbose = FALSE,
+        additional_variables = additional_variables
+    ))
 
     if (isTRUE(wts)) {
-      tmp <- insight::get_weights(model)
-      if (is.numeric(tmp) && length(tmp) == nrow(out)) {
-        out[["marginaleffects_wts_internal"]] <- tmp
-      }
+        tmp <- insight::get_weights(model)
+        if (is.numeric(tmp) && length(tmp) == nrow(out)) {
+            out[["marginaleffects_wts_internal"]] <- tmp
+        }
     }
 
     # iv_robust and some others
     if (is.null(out)) {
-        out <- evalup(model[["call"]][["data"]])
+        out <- eval.parent(model[["call"]][["data"]])
     }
 
     if (is.null(out)) {
-        out <- evalup(attr(model, "call")$data)
+        out <- eval.parent(attr(model, "call")$data)
     }
 
-    out <- as.data.frame(out)
+    out <- unpack_matrix_1col(out)
+    data.table::setDT(out)
     out <- set_variable_class(out, model = model)
     return(out)
 }
 
 
 set_variable_class <- function(modeldata, model = NULL) {
-
     if (is.null(modeldata)) return(modeldata)
 
     # this can be costly on large datasets, when only a portion of
@@ -112,7 +138,8 @@ set_variable_class <- function(modeldata, model = NULL) {
     if (is.null(model)) {
         variables <- tryCatch(
             unlist(insight::find_variables(model, flatten = TRUE), use.names = FALSE),
-            error = function(e) NULL)
+            error = function(e) NULL
+        )
     }
     if (is.null(variables)) variables <- colnames(modeldata)
 
@@ -126,7 +153,8 @@ set_variable_class <- function(modeldata, model = NULL) {
             cl[col] <- "character"
         } else if (is.factor(out[[col]])) {
             cl[col] <- "factor"
-        } else if (inherits(out[[col]], "Surv")) { # is numeric but breaks the %in% 0:1 check
+        } else if (inherits(out[[col]], "Surv")) {
+            # is numeric but breaks the %in% 0:1 check
             cl[col] <- "other"
         } else if (is.numeric(out[[col]])) {
             if (is_binary(out[[col]])) {
@@ -151,7 +179,8 @@ set_variable_class <- function(modeldata, model = NULL) {
     idx <- gsub(
         regex,
         "\\2",
-        Filter(function(x) grepl(regex, x), te))
+        Filter(function(x) grepl(regex, x), te)
+    )
     cl[names(cl) %in% idx] <- "factor"
 
     # in-formula categoricals
@@ -159,7 +188,8 @@ set_variable_class <- function(modeldata, model = NULL) {
     idx <- gsub(
         regex,
         "\\2",
-        Filter(function(x) grepl(regex, x), te))
+        Filter(function(x) grepl(regex, x), te)
+    )
     cl[names(cl) %in% idx] <- "strata"
 
     # in-formula numeric
@@ -167,7 +197,8 @@ set_variable_class <- function(modeldata, model = NULL) {
     idx <- gsub(
         regex,
         "\\1",
-        Filter(function(x) grepl(regex, x), te))
+        Filter(function(x) grepl(regex, x), te)
+    )
     cl[names(cl) %in% idx] <- "numeric"
 
     # in-formula logical
@@ -175,7 +206,8 @@ set_variable_class <- function(modeldata, model = NULL) {
     idx <- gsub(
         regex,
         "\\1",
-        Filter(function(x) grepl(regex, x), te))
+        Filter(function(x) grepl(regex, x), te)
+    )
     cl[names(cl) %in% idx] <- "logical"
 
     # in-formula: fixest::i()
@@ -201,7 +233,6 @@ set_variable_class <- function(modeldata, model = NULL) {
 
 
 get_variable_class <- function(newdata, variable = NULL, compare = NULL) {
-
     if ("marginaleffects_variable_class" %in% names(attributes(newdata))) {
         cl <- attributes(newdata)$marginaleffects_variable_class
     } else {
@@ -211,20 +242,21 @@ get_variable_class <- function(newdata, variable = NULL, compare = NULL) {
 
     if (is.null(compare) && is.null(variable)) {
         out <- cl
-
     } else if (is.null(compare)) {
         out <- cl[variable]
-
     } else if (is.null(variable)) {
         if (isTRUE(compare == "categorical")) {
-            out <- cl[cl %in% c("factor", "character", "logical", "strata", "cluster", "binary")]
+            out <- cl[
+                cl %in%
+                    c("factor", "character", "logical", "strata", "cluster", "binary")
+            ]
         } else {
             out <- cl[cl %in% compare]
         }
-
     } else {
         if (isTRUE(compare == "categorical")) {
-            out <- cl[variable] %in% c("factor", "character", "logical", "strata", "cluster", "binary")
+            out <- cl[variable] %in%
+                c("factor", "character", "logical", "strata", "cluster", "binary")
         } else {
             out <- cl[variable] %in% compare
         }
