@@ -4,7 +4,9 @@
 get_coef.data.frame <- function(model, ...) {
     checkmate::assert_data_frame(model)
     if (!"estimate" %in% colnames(model)) {
-        insight::format_error("The model object is a data.frame but doesn't contain the column 'estimate'. Make sure these columns are present")
+        insight::format_error(
+            "The model object is a data.frame but doesn't contain the column 'estimate'. Make sure these columns are present"
+        )
     }
 
     out <- model$estimate
@@ -22,6 +24,6 @@ get_coef.data.frame <- function(model, ...) {
 #' @rdname set_coef
 #' @export
 set_coef.data.frame <- function(model, coefs, ...) {
-  model$estimate = coefs
-  return(model)
+    model$estimate = coefs
+    return(model)
 }
