@@ -4,7 +4,7 @@
 set_coef.multinom <- function(model, coefs, ...) {
     # internally, coefficients are held in the `wts` vector, with 0s
     # interspersed. When transforming that vector to a matrix, we see that the
-    # first row and first column are all zeros. 
+    # first row and first column are all zeros.
     # NOTE: must use `newdata` in predict otherwise returns stored object.
     b_original <- get_coef(model)
     model$wts[match(b_original, model$wts)] <- coefs
@@ -19,7 +19,8 @@ get_coef.multinom <- function(model, ...) {
     out <- insight::get_parameters(model, ...)
     out <- stats::setNames(
         out$Estimate,
-        sprintf("%s:%s", out$Response, out$Parameter))
+        sprintf("%s:%s", out$Response, out$Parameter)
+    )
     return(out)
 }
 
@@ -41,11 +42,12 @@ get_group_names.multinom <- function(model, ...) {
 #' @include get_predict.R
 #' @rdname get_predict
 #' @export
-get_predict.multinom <- function(model,
-                                 newdata = insight::get_data(model),
-                                 type = "probs",
-                                 ...) {
-
+get_predict.multinom <- function(
+    model,
+    newdata = insight::get_data(model),
+    type = "probs",
+    ...
+) {
     type <- sanitize_type(model, type, calling_function = "predictions")
 
     is_latent <- is_mclogit <- is_nnet <- FALSE
@@ -53,21 +55,17 @@ get_predict.multinom <- function(model,
         is_latent <- TRUE
         is_mclogit <- TRUE
         type <- "link"
-
     } else if (isTRUE(type == "latent") && inherits(model, "multinom")) {
         is_latent <- TRUE
         is_nnet <- TRUE
         type <- "probs"
-    } 
+    }
 
     # needed because `predict.multinom` uses `data` rather than `newdata`
-    pred <- stats::predict(model,
-                           newdata = newdata,
-                           type = type,
-                           ...)
+    pred <- stats::predict(model, newdata = newdata, type = type, ...)
 
     # atomic vector means there is only one row in `newdata`
-    # two levels DV returns a vector 
+    # two levels DV returns a vector
     if (isTRUE(checkmate::check_atomic_vector(pred))) {
         y_original <- sort(unique(insight::get_response(model)))
         two_levels <- length(y_original) == 2
@@ -77,20 +75,20 @@ get_predict.multinom <- function(model,
         } else {
             pred <- matrix(pred, nrow = 1, dimnames = list(NULL, names(pred)))
         }
-
     }
 
     if (is_latent && is_mclogit) {
         missing_level <- as.character(unique(insight::get_response(model)))
         missing_level <- setdiff(missing_level, colnames(pred))
-        if (length(missing_level == 1)) {
+        if (length(missing_level) == 1) {
             pred <- cbind(0, pred)
             colnames(pred)[1] <- missing_level
             pred <- pred - rowMeans(pred)
         } else {
-            insight::format_error("Unable to compute predictions on the latent scale.")
+            insight::format_error(
+                "Unable to compute predictions on the latent scale."
+            )
         }
-
     } else if (is_latent && is_nnet) {
         inverse_softMax <- function(mu) {
             log_mu <- log(mu)
@@ -99,11 +97,11 @@ get_predict.multinom <- function(model,
         pred <- inverse_softMax(pred)
     }
 
-
     # matrix with outcome levels as columns
     out <- data.frame(
         group = rep(colnames(pred), each = nrow(pred)),
-        estimate = c(pred))
+        estimate = c(pred)
+    )
     out$group <- group_to_factor(out$group, model)
 
     # usually when `newdata` is supplied by `comparisons`
@@ -115,4 +113,3 @@ get_predict.multinom <- function(model,
 
     return(out)
 }
-
